import { sessionStorageTool } from "@/utils/storage";
import { SESSION_STORAGE_KEYS } from "@/constants/storage";
import { loginOutHttp } from "@/apis/common";
import router from "@/routes";
import type { AxiosResponse } from "axios";

/** 退出登录 */
export const exitLogin = () => {
  loginOutHttp();
  sessionStorageTool.remove(SESSION_STORAGE_KEYS.LOGIN_RESULT);
  sessionStorageTool.remove(SESSION_STORAGE_KEYS.USER_INFO);
  router.replace({ name: "login" });
};

/** 提取文件名 */
export const extractFileName = (str: string) => {
  if (/fileName=([^;\s]*)/gi.test(str)) {
    return decodeURIComponent(RegExp.$1);
  }
  return "";
};

/** 下载文件 */
export const download = (blob: Blob, filename: string = "") => {
  const a = document.createElement("a");
  a.download = filename;
  const blobUrl = URL.createObjectURL(blob);
  a.href = blobUrl;
  document.body.appendChild(a);
  a.click();
  a.remove();
  URL.revokeObjectURL(blobUrl);
};

export const downloadBlob = (response: AxiosResponse) => {
  if(response){
    const fileName = extractFileName(response.headers["content-disposition"])
    download(response.data, fileName)
  }
};
